pub struct Clock(pub Clock);Expand description
A representation of network time.
All members of Clock start from 0 upon network boot.
Tuple Fields
0: ClockImplementations
Sourceimpl Clock
impl Clock
Sourcepub fn epoch_start_timestamp(&self) -> UnixTimestamp
pub fn epoch_start_timestamp(&self) -> UnixTimestamp
int: The timestamp of the first Slot in this Epoch.
Sourcepub fn leader_schedule_epoch(&self) -> Epoch
pub fn leader_schedule_epoch(&self) -> Epoch
int: The future Epoch for which the leader schedule has most recently been calculated.
Sourcepub fn unix_timestamp(&self) -> UnixTimestamp
pub fn unix_timestamp(&self) -> UnixTimestamp
int: The approximate real world time of the current slot.
pub fn __richcmp__(&self, other: &Self, op: CompareOp) -> PyResult<bool>
pub fn __bytes__<'a>(&self, py: Python<'a>) -> &'a PyBytes
pub fn __str__(&self) -> String
pub fn __repr__(&self) -> String
pub fn __reduce__(&self) -> PyResult<(PyObject, PyObject)>
Sourcepub fn from_bytes(data: &[u8]) -> PyResult<Self>
pub fn from_bytes(data: &[u8]) -> PyResult<Self>
Deserialize from bytes.
Args: data (bytes): the serialized object.
Returns: the deserialized object.